use hermann;


drop table if exists Users;
create table Users (
	User_Login CHAR(10) not null,
	User_Pass CHAR(10) not null,
	primary key (User_Login));

drop table if exists Events;
create table Events (
	Day INT(10) unsigned not null,
	Event_Start INT(10) unsigned not null,
	Event_End INT(10) unsigned not null,
	User_Login CHAR(10) not null,
	primary key (User_Login, Event_Start, Event_End, Day));

insert into Users values ('admin', 'pass');
