<%@ page import="java.util.*, com.example.model.*" %>
<html>
<head><title>Sign Up For Group F Scheduler</title>
<script language='javascript' src='genvalidationv5.js'></script>
<script type="text/javascript">
function setFlagSignUp()
{
var flag = document.getElementById("formflag");
flag.value=3;
}
function setFlagLogOut()
{
var flag = document.getElementById("formflag");
flag.value=4;
}
</script>
</head>
<form method="post" action="Schedule.do" name="new_user">
<h1>Welcome To Group F Scheduler</h1>
<hr color=blue>
<p>
  Please fill in all the required information below.  Soon
  You will have an account with Group F Scheduler.  
</p>

<b>Desired Login Name:</b><br/>
<input type="text" name="login"><br/><br/>
<b>Password:</b><br/>
<input type="password" name="pw"><br/><br/>
<b>Confirm Password:</b><br/>
<input type="password" name="cpw"><br/>
<font color="red">
<%
    String message = (String)request.getAttribute("message");
    out.println(message);
%>
</font>
<br/>
<input type="hidden" name="formflag" value="-1" id="formflag">
<input type="submit" name="new_user" value="Submit" onclick="setFlagSignUp()">
<input type="submit" name="logout" value="Exit" onclick="setFlagLogOut()">
<script language='JavaScript'>
var loginValidator = new Validator("new_user");
loginValidator.addValidation("login","req","Please fill in username");
loginValidator.addValidation("pw","req","Please fill in password");
loginValidator.addValidation("cpw","req","Please confirm your password");    
     </script> 
</form>
</body>
</html>

